<?php

namespace Lavalite\Industry\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Lavalite\Industry\Http\Requests\IndustryUserRequest;
use Lavalite\Industry\Interfaces\IndustryRepositoryInterface;
use Response;
use User;

class IndustryUserController extends UserController
{
    /**
     * Initialize industry controller.
     *
     * @param type IndustryRepositoryInterface $industry
     *
     * @return type
     */
    public function __construct(IndustryRepositoryInterface $industry)
    {
        $this->model = $industry;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(IndustryUserRequest $request)
    {
        $industries = $this->model->all();

        $this->theme->prependTitle(trans('industry::industry.names').' :: ');

        return $this->theme->of('industry::user.industry.index', compact('industries'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(IndustryUserRequest $request, $role, $id)
    {
        $industry = $this->model->find($id);

        return $this->theme->of('industry::user.industry.show', compact('industry'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(IndustryUserRequest $request)
    {
        $industry = $this->model->findOrNew(0);

        Former::populate($industry);

        return $this->theme->of('industry::user.industry.create', compact('industry'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(IndustryUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $industry = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('industry::industry.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(IndustryUserRequest $request, $role, $id)
    {
        $industry = $this->model->find($id);

        Former::populate($industry);

        return $this->theme->of('industry::user.industry.edit', compact('industry'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(IndustryUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $industry = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('industry::industry.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(IndustryUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('industry::industry.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
