<?php

namespace Lavalite\Industry\Http\Requests;

use App\Http\Requests\Request;
use User;

class IndustryAdminRequest extends Request
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize(\Illuminate\Http\Request $request)
    {
        // Determine if the user is authorized to create an entry,
        if ($request->isMethod('POST') || $request->is('*/create')) {
            return User::can('industry.industry.create');
        }

        // Determine if the user is authorized to update an entry,
        if ($request->isMethod('PUT') || $request->isMethod('PATCH') || $request->is('*/edit')) {
            return User::can('industry.industry.edit');
        }

        // Determine if the user is authorized to delete an entry,
        if ($request->isMethod('DELETE')) {
            return User::can('industry.industry.delete');
        }

        // Determine if the user is authorized to view the module.
        return User::can('industry.industry.view');
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules(\Illuminate\Http\Request $request)
    {
        // validation rule for create request.
        if ($request->isMethod('POST')) {
            return [
                'image'               => 'required',
                'logo'                => 'required',
                'description'         => 'required',
                'building'            => 'required',
                'street'              => 'required',
                'town'                => 'required',
                'state'               => 'required',
                'country'             => 'required',
                'pin'                 => 'required',
                'phone'               => 'required',
                'email'               => 'required',
                'website'             => 'required',
                'video'               => 'required',
                'google'              => 'required',
                'facebook'            => 'required',
                'twitter'             => 'required',
                'linkedin'            => 'required',
                'location'            => 'required',
                'status'              => 'required',
            ];
        }

        // Validation rule for update request.
        if ($request->isMethod('PUT') || $request->isMethod('PATCH')) {
            return [
                'image'               => 'required',
                'logo'                => 'required',
                'description'         => 'required',
                'building'            => 'required',
                'street'              => 'required',
                'town'                => 'required',
                'state'               => 'required',
                'country'             => 'required',
                'pin'                 => 'required',
                'phone'               => 'required',
                'email'               => 'required',
                'website'             => 'required',
                'video'               => 'required',
                'google'              => 'required',
                'facebook'            => 'required',
                'twitter'             => 'required',
                'linkedin'            => 'required',
                'location'            => 'required',
                'status'              => 'required',
            ];
        }

        // Default validation rule.
        return [

        ];
    }
}
